summaryrefslogtreecommitdiffstats
path: root/kcontrol/kcontrol/proxywidget.cpp
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-01-19 01:42:14 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-01-19 01:42:14 +0000
commit8155225c9be993acc0512956416d195edfef4eb9 (patch)
treede4f3cd17614fc67e47eefabcdbe2fbe170c9be7 /kcontrol/kcontrol/proxywidget.cpp
parent364641b8e0279758d236af39abd138d379328a19 (diff)
downloadtdebase-8155225c9be993acc0512956416d195edfef4eb9.tar.gz
tdebase-8155225c9be993acc0512956416d195edfef4eb9.zip
Enable compilation with TQt for Qt4 3.4.0 TP2
This should not break compatibility with TQt for Qt3; if it does please fix it ASAP! git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdebase@1215552 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kcontrol/kcontrol/proxywidget.cpp')
-rw-r--r--kcontrol/kcontrol/proxywidget.cpp24
1 files changed, 12 insertions, 12 deletions
diff --git a/kcontrol/kcontrol/proxywidget.cpp b/kcontrol/kcontrol/proxywidget.cpp
index b8f83c5fc..f3b80bda0 100644
--- a/kcontrol/kcontrol/proxywidget.cpp
+++ b/kcontrol/kcontrol/proxywidget.cpp
@@ -39,7 +39,7 @@
#include <kdebug.h>
#include <tqtimer.h>
-class WhatsThis : public QWhatsThis
+class WhatsThis : public TQWhatsThis
{
public:
WhatsThis( ProxyWidget* parent )
@@ -60,7 +60,7 @@ private:
////////////////////////////////////////////////////////////////////////////////////////////////////////
-static void setVisible(TQPushButton *btn, bool vis)
+static void trinity_setVisible(TQPushButton *btn, bool vis)
{
if (vis)
btn->show();
@@ -72,7 +72,7 @@ static void setVisible(TQPushButton *btn, bool vis)
////////////////////////////////////////////////////////////////////////////////////////////////////////
-class RootInfoWidget : public QLabel
+class RootInfoWidget : public TQLabel
{
public:
RootInfoWidget(TQWidget *parent, const char *name);
@@ -100,7 +100,7 @@ RootInfoWidget::RootInfoWidget(TQWidget *parent, const char *name = 0)
////////////////////////////////////////////////////////////////////////////////////////////////////////
-class ProxyView : public QScrollView
+class ProxyView : public TQScrollView
{
public:
ProxyView(KCModule *client, const TQString& title, TQWidget *parent, bool run_as_root, const char *name);
@@ -113,14 +113,14 @@ private:
bool scroll;
};
-class ProxyContentWidget : public QWidget
+class ProxyContentWidget : public TQWidget
{
public:
ProxyContentWidget( TQWidget* parent ) : TQWidget( parent ) {}
~ProxyContentWidget(){}
// this should be really done by qscrollview in AutoOneFit mode!
- TQSize sizeHint() const { return minimumSizeHint(); }
+ TQSize tqsizeHint() const { return tqminimumSizeHint(); }
};
@@ -144,7 +144,7 @@ ProxyView::ProxyView(KCModule *_client, const TQString&, TQWidget *parent, bool
}
client->reparent(contentWidget,0,TQPoint(0,0),true);
vbox->addWidget( client );
- vbox->activate(); // make sure we have a proper minimumSizeHint
+ vbox->activate(); // make sure we have a proper tqminimumSizeHint
addChild(contentWidget);
}
@@ -215,11 +215,11 @@ ProxyWidget::ProxyWidget(KCModule *client, TQString title, const char *name,
// only enable the requested buttons
int b = _client->buttons();
- setVisible(_handbook, (b & KCModule::Help));
- setVisible(_default, mayModify && (b & KCModule::Default));
- setVisible(_apply, mayModify && (b & KCModule::Apply));
- setVisible(_reset, mayModify && (b & KCModule::Apply));
- setVisible(_root, run_as_root);
+ trinity_setVisible(_handbook, (b & KCModule::Help));
+ trinity_setVisible(_default, mayModify && (b & KCModule::Default));
+ trinity_setVisible(_apply, mayModify && (b & KCModule::Apply));
+ trinity_setVisible(_reset, mayModify && (b & KCModule::Apply));
+ trinity_setVisible(_root, run_as_root);
// disable initial buttons
_apply->setEnabled( false );